@@ -1,6 +1,5 @@
-pub fn union<T: PartialEq + Clone>(vector1: &Vec<T>, vector2: &Vec<T>) -> Vec<T>
-{
-    let mut unioned: Vec<T> = vec!();
+pub fn union<T: PartialEq + Clone>(vector1: &[T], vector2: &[T]) -> Vec<T> {
+    let mut unioned: Vec<T> = vec![];
     for element in vector1 {
         unioned.push(element.clone());
     }
@@ -9,18 +8,17 @@ pub fn union<T: PartialEq + Clone>(vector1: &Vec<T>, vector2: &Vec<T>) -> Vec<T>
             unioned.push(element.clone());
         }
     }
-    return unioned;
+    unioned
 }
 
-pub fn intersect<T: PartialEq + Clone>(vector1: &Vec<T>, vector2: &Vec<T>) -> Vec<T>
-{
-    let mut intersected = vec!();
+pub fn intersect<T: PartialEq + Clone>(vector1: &[T], vector2: &[T]) -> Vec<T> {
+    let mut intersected = vec![];
     for element in vector1 {
         if vector2.contains(element) {
             intersected.push(element.clone());
         }
     }
-    return intersected;
+    intersected
 }
 
 // pub fn outersect<T: PartialEq + Clone>(vector1: &Vec<T>, vector2: &Vec<T>) -> Vec<T>
@@ -39,13 +37,12 @@ pub fn intersect<T: PartialEq + Clone>(vector1: &Vec<T>, vector2: &Vec<T>) -> Ve
 //     return outersected;
 // }
 
-pub fn outersect_left<T: PartialEq + Clone>(vector1: &Vec<T>, vector2: &Vec<T>) -> Vec<T>
-{
-    let mut outersected = vec!();
+pub fn outersect_left<T: PartialEq + Clone>(vector1: &[T], vector2: &[T]) -> Vec<T> {
+    let mut outersected = vec![];
     for element in vector1 {
         if !vector2.contains(element) {
             outersected.push(element.clone());
         }
     }
-    return outersected;
-}
\ No newline at end of file
+    outersected
+}
